Class: CalendarApi::Attachment

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/attachment.rb

Overview

A file attachment for an event.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(file_url: SKIP, title: SKIP, mime_type: SKIP, icon_link: SKIP, file_id: SKIP, additional_properties: nil) ⇒ Attachment

Returns a new instance of Attachment.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/calendar_api/models/attachment.rb', line 59

def initialize(file_url: SKIP, title: SKIP, mime_type: SKIP,
               icon_link: SKIP, file_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @file_url = file_url unless file_url == SKIP
  @title = title unless title == SKIP
  @mime_type = mime_type unless mime_type == SKIP
  @icon_link = icon_link unless icon_link == SKIP
  @file_id = file_id unless file_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#file_idString

ID of the attached file. Only populated for Google Drive files.

Returns:

  • (String)


30
31
32
# File 'lib/calendar_api/models/attachment.rb', line 30

def file_id
  @file_id
end

#file_urlString

URL link to the attachment. Required when adding an attachment.

Returns:

  • (String)


14
15
16
# File 'lib/calendar_api/models/attachment.rb', line 14

def file_url
  @file_url
end

URL link to the attachment’s icon.

Returns:

  • (String)


26
27
28
# File 'lib/calendar_api/models/attachment.rb', line 26

def icon_link
  @icon_link
end

#mime_typeString

Internet media type (MIME type) of the attachment.

Returns:

  • (String)


22
23
24
# File 'lib/calendar_api/models/attachment.rb', line 22

def mime_type
  @mime_type
end

#titleString

Attachment title.

Returns:

  • (String)


18
19
20
# File 'lib/calendar_api/models/attachment.rb', line 18

def title
  @title
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/calendar_api/models/attachment.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  file_url = hash.key?('fileUrl') ? hash['fileUrl'] : SKIP
  title = hash.key?('title') ? hash['title'] : SKIP
  mime_type = hash.key?('mimeType') ? hash['mimeType'] : SKIP
  icon_link = hash.key?('iconLink') ? hash['iconLink'] : SKIP
  file_id = hash.key?('fileId') ? hash['fileId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Attachment.new(file_url: file_url,
                 title: title,
                 mime_type: mime_type,
                 icon_link: icon_link,
                 file_id: file_id,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/calendar_api/models/attachment.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['file_url'] = 'fileUrl'
  @_hash['title'] = 'title'
  @_hash['mime_type'] = 'mimeType'
  @_hash['icon_link'] = 'iconLink'
  @_hash['file_id'] = 'fileId'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/calendar_api/models/attachment.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/calendar_api/models/attachment.rb', line 44

def self.optionals
  %w[
    file_url
    title
    mime_type
    icon_link
    file_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
113
# File 'lib/calendar_api/models/attachment.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} file_url: #{@file_url.inspect}, title: #{@title.inspect}, mime_type:"\
  " #{@mime_type.inspect}, icon_link: #{@icon_link.inspect}, file_id: #{@file_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
105
# File 'lib/calendar_api/models/attachment.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} file_url: #{@file_url}, title: #{@title}, mime_type: #{@mime_type},"\
  " icon_link: #{@icon_link}, file_id: #{@file_id}, additional_properties:"\
  " #{@additional_properties}>"
end