Class: CalendarApi::CalendarListEntryConferenceProperties

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/calendar_list_entry_conference_properties.rb

Overview

Conference properties for this calendar.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(allowed_conference_solution_types: SKIP, additional_properties: nil) ⇒ CalendarListEntryConferenceProperties

Returns a new instance of CalendarListEntryConferenceProperties.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/calendar_api/models/calendar_list_entry_conference_properties.rb', line 36

def initialize(allowed_conference_solution_types: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless allowed_conference_solution_types == SKIP
    @allowed_conference_solution_types =
      allowed_conference_solution_types
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#allowed_conference_solution_typesArray[ConferenceSolutionType]

The types of conference solutions supported for this calendar.

Returns:



14
15
16
# File 'lib/calendar_api/models/calendar_list_entry_conference_properties.rb', line 14

def allowed_conference_solution_types
  @allowed_conference_solution_types
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/calendar_api/models/calendar_list_entry_conference_properties.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  allowed_conference_solution_types =
    hash.key?('allowedConferenceSolutionTypes') ? hash['allowedConferenceSolutionTypes'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CalendarListEntryConferenceProperties.new(allowed_conference_solution_types: allowed_conference_solution_types,
                                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
22
# File 'lib/calendar_api/models/calendar_list_entry_conference_properties.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['allowed_conference_solution_types'] =
    'allowedConferenceSolutionTypes'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/calendar_api/models/calendar_list_entry_conference_properties.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/calendar_api/models/calendar_list_entry_conference_properties.rb', line 25

def self.optionals
  %w[
    allowed_conference_solution_types
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
81
# File 'lib/calendar_api/models/calendar_list_entry_conference_properties.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} allowed_conference_solution_types:"\
  " #{@allowed_conference_solution_types.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
73
# File 'lib/calendar_api/models/calendar_list_entry_conference_properties.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} allowed_conference_solution_types: #{@allowed_conference_solution_types},"\
  " additional_properties: #{@additional_properties}>"
end