Class: CalendarApi::CalendarListEntryNotificationSettings

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/calendar_list_entry_notification_settings.rb

Overview

The notifications the authenticated user receives for this calendar.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(notifications: SKIP, additional_properties: nil) ⇒ CalendarListEntryNotificationSettings

Returns a new instance of CalendarListEntryNotificationSettings.



35
36
37
38
39
40
41
# File 'lib/calendar_api/models/calendar_list_entry_notification_settings.rb', line 35

def initialize(notifications: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @notifications = notifications unless notifications == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#notificationsArray[CalendarNotification]

List of notification settings for this calendar.

Returns:



14
15
16
# File 'lib/calendar_api/models/calendar_list_entry_notification_settings.rb', line 14

def notifications
  @notifications
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/calendar_api/models/calendar_list_entry_notification_settings.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  notifications = nil
  unless hash['notifications'].nil?
    notifications = []
    hash['notifications'].each do |structure|
      notifications << (CalendarNotification.from_hash(structure) if structure)
    end
  end

  notifications = SKIP unless hash.key?('notifications')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CalendarListEntryNotificationSettings.new(notifications: notifications,
                                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/calendar_api/models/calendar_list_entry_notification_settings.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['notifications'] = 'notifications'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/calendar_api/models/calendar_list_entry_notification_settings.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/calendar_api/models/calendar_list_entry_notification_settings.rb', line 24

def self.optionals
  %w[
    notifications
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/calendar_api/models/calendar_list_entry_notification_settings.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} notifications: #{@notifications.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/calendar_api/models/calendar_list_entry_notification_settings.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} notifications: #{@notifications}, additional_properties:"\
  " #{@additional_properties}>"
end