Class: CalendarApi::CalendarNotification

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/calendar_notification.rb

Overview

A notification setting for a calendar.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type: SKIP, method: SKIP, additional_properties: nil) ⇒ CalendarNotification

Returns a new instance of CalendarNotification.



42
43
44
45
46
47
48
49
# File 'lib/calendar_api/models/calendar_notification.rb', line 42

def initialize(type: SKIP, method: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type unless type == SKIP
  @method = method unless method == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#methodCalendarNotificationMethod

The method used to deliver the notification. Currently only “email” is supported.



19
20
21
# File 'lib/calendar_api/models/calendar_notification.rb', line 19

def method
  @method
end

#typeCalendarNotificationType

The type of notification.



14
15
16
# File 'lib/calendar_api/models/calendar_notification.rb', line 14

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/calendar_api/models/calendar_notification.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : SKIP
  method = hash.key?('method') ? hash['method'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CalendarNotification.new(type: type,
                           method: method,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/calendar_api/models/calendar_notification.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['method'] = 'method'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/calendar_api/models/calendar_notification.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/calendar_api/models/calendar_notification.rb', line 30

def self.optionals
  %w[
    type
    method
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/calendar_api/models/calendar_notification.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, method: #{@method.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/calendar_api/models/calendar_notification.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, method: #{@method}, additional_properties:"\
  " #{@additional_properties}>"
end