Class: CalendarApi::ChannelParams

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/channel_params.rb

Overview

Additional parameters controlling delivery channel behavior.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ttl: SKIP, additional_properties: nil) ⇒ ChannelParams

Returns a new instance of ChannelParams.



36
37
38
39
40
41
42
# File 'lib/calendar_api/models/channel_params.rb', line 36

def initialize(ttl: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @ttl = ttl unless ttl == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#ttlString

The time-to-live in seconds for the notification channel. Default is 604800 (1 week).

Returns:

  • (String)


15
16
17
# File 'lib/calendar_api/models/channel_params.rb', line 15

def ttl
  @ttl
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/calendar_api/models/channel_params.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ttl = hash.key?('ttl') ? hash['ttl'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ChannelParams.new(ttl: ttl,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/calendar_api/models/channel_params.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ttl'] = 'ttl'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/calendar_api/models/channel_params.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/calendar_api/models/channel_params.rb', line 25

def self.optionals
  %w[
    ttl
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
# File 'lib/calendar_api/models/channel_params.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ttl: #{@ttl.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
# File 'lib/calendar_api/models/channel_params.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ttl: #{@ttl}, additional_properties: #{@additional_properties}>"
end