Class: CalendarApi::ChannelsApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/calendar_api/apis/channels_api.rb

Overview

ChannelsApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from CalendarApi::BaseApi

Instance Method Details

#stop_channel(body) ⇒ ApiResponse

Stops receiving push notifications for the specified channel. This is required to clean up channels created by the watchEvents operation. a notification channel.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/calendar_api/apis/channels_api.rb', line 14

def stop_channel(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/channels/stop',
                                 Server::DEFAULT)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('oauth2')))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true)
                .local_error('400',
                             'Bad request — invalid parameters or request body.',
                             ErrorResponseError1Exception)
                .local_error('401',
                             'Authentication required or credentials are invalid.',
                             ErrorResponseError1Exception)
                .local_error('403',
                             'Insufficient permissions for the requested resource.',
                             ErrorResponseError1Exception)
                .local_error('404',
                             'The requested resource was not found.',
                             ErrorResponseError1Exception))
    .execute
end