Class: CalendarApi::ConferenceCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/conference_create_request.rb

Overview

A request to generate a new conference and attach it to the event.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id: SKIP, conference_solution_key: SKIP, status: SKIP, additional_properties: nil) ⇒ ConferenceCreateRequest

Returns a new instance of ConferenceCreateRequest.



48
49
50
51
52
53
54
55
56
57
# File 'lib/calendar_api/models/conference_create_request.rb', line 48

def initialize(request_id: SKIP, conference_solution_key: SKIP,
               status: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_id = request_id unless request_id == SKIP
  @conference_solution_key = conference_solution_key unless conference_solution_key == SKIP
  @status = status unless status == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#conference_solution_keyConferenceSolutionKey

Identifies a conference solution type.



19
20
21
# File 'lib/calendar_api/models/conference_create_request.rb', line 19

def conference_solution_key
  @conference_solution_key
end

#request_idString

Unique client-generated ID for this request. Clients should regenerate this ID for every new request.

Returns:

  • (String)


15
16
17
# File 'lib/calendar_api/models/conference_create_request.rb', line 15

def request_id
  @request_id
end

#statusConferenceCreateRequestStatus

Status of the conference create request.



23
24
25
# File 'lib/calendar_api/models/conference_create_request.rb', line 23

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/calendar_api/models/conference_create_request.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('requestId') ? hash['requestId'] : SKIP
  conference_solution_key = ConferenceSolutionKey.from_hash(hash['conferenceSolutionKey']) if
    hash['conferenceSolutionKey']
  status = ConferenceCreateRequestStatus.from_hash(hash['status']) if hash['status']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConferenceCreateRequest.new(request_id: request_id,
                              conference_solution_key: conference_solution_key,
                              status: status,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/calendar_api/models/conference_create_request.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'requestId'
  @_hash['conference_solution_key'] = 'conferenceSolutionKey'
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/calendar_api/models/conference_create_request.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/calendar_api/models/conference_create_request.rb', line 35

def self.optionals
  %w[
    request_id
    conference_solution_key
    status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/calendar_api/models/conference_create_request.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id.inspect}, conference_solution_key:"\
  " #{@conference_solution_key.inspect}, status: #{@status.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
89
# File 'lib/calendar_api/models/conference_create_request.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id}, conference_solution_key:"\
  " #{@conference_solution_key}, status: #{@status}, additional_properties:"\
  " #{@additional_properties}>"
end