Class: CalendarApi::ErrorResponseErrorErrorsItems

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/error_response_error_errors_items.rb

Overview

ErrorResponseErrorErrorsItems object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(domain: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) ⇒ ErrorResponseErrorErrorsItems

Returns a new instance of ErrorResponseErrorErrorsItems.



47
48
49
50
51
52
53
54
55
56
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 47

def initialize(domain: SKIP, reason: SKIP, message: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @domain = domain unless domain == SKIP
  @reason = reason unless reason == SKIP
  @message = message unless message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#domainString

The error domain.

Returns:

  • (String)


14
15
16
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 14

def domain
  @domain
end

#messageString

A human-readable error message.

Returns:

  • (String)


22
23
24
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 22

def message
  @message
end

#reasonString

The error reason code.

Returns:

  • (String)


18
19
20
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 18

def reason
  @reason
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  domain = hash.key?('domain') ? hash['domain'] : SKIP
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ErrorResponseErrorErrorsItems.new(domain: domain,
                                    reason: reason,
                                    message: message,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['domain'] = 'domain'
  @_hash['reason'] = 'reason'
  @_hash['message'] = 'message'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 34

def self.optionals
  %w[
    domain
    reason
    message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} domain: #{@domain.inspect}, reason: #{@reason.inspect}, message:"\
  " #{@message.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} domain: #{@domain}, reason: #{@reason}, message: #{@message},"\
  " additional_properties: #{@additional_properties}>"
end