Class: CalendarApi::Event

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/event.rb

Overview

A Google Calendar event resource.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(start:, mend:, kind: 'calendar#event', etag: SKIP, id: SKIP, status: SKIP, html_link: SKIP, created: SKIP, updated: SKIP, summary: SKIP, description: SKIP, location: SKIP, color_id: SKIP, creator: SKIP, organizer: SKIP, end_time_unspecified: false, recurrence: SKIP, recurring_event_id: SKIP, original_start_time: SKIP, transparency: EventTransparency::OPAQUE, visibility: EventVisibility::DEFAULT, i_cal_uid: SKIP, sequence: SKIP, attendees: SKIP, attendees_omitted: false, hangout_link: SKIP, conference_data: SKIP, guests_can_invite_others: true, guests_can_modify: false, guests_can_see_other_guests: true, private_copy: false, locked: false, reminders: SKIP, source: SKIP, event_type: SKIP, extended_properties: SKIP, attachments: SKIP, birthday_properties: SKIP, out_of_office_properties: SKIP, focus_time_properties: SKIP, working_location_properties: SKIP, additional_properties: nil) ⇒ Event

Returns a new instance of Event.



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/calendar_api/models/event.rb', line 289

def initialize(start:, mend:, kind: 'calendar#event', etag: SKIP, id: SKIP,
               status: SKIP, html_link: SKIP, created: SKIP, updated: SKIP,
               summary: SKIP, description: SKIP, location: SKIP,
               color_id: SKIP, creator: SKIP, organizer: SKIP,
               end_time_unspecified: false, recurrence: SKIP,
               recurring_event_id: SKIP, original_start_time: SKIP,
               transparency: EventTransparency::OPAQUE,
               visibility: EventVisibility::DEFAULT, i_cal_uid: SKIP,
               sequence: SKIP, attendees: SKIP, attendees_omitted: false,
               hangout_link: SKIP, conference_data: SKIP,
               guests_can_invite_others: true, guests_can_modify: false,
               guests_can_see_other_guests: true, private_copy: false,
               locked: false, reminders: SKIP, source: SKIP,
               event_type: SKIP, extended_properties: SKIP,
               attachments: SKIP, birthday_properties: SKIP,
               out_of_office_properties: SKIP, focus_time_properties: SKIP,
               working_location_properties: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @kind = kind unless kind == SKIP
  @etag = etag unless etag == SKIP
  @id = id unless id == SKIP
  @status = status unless status == SKIP
  @html_link = html_link unless html_link == SKIP
  @created = created unless created == SKIP
  @updated = updated unless updated == SKIP
  @summary = summary unless summary == SKIP
  @description = description unless description == SKIP
  @location = location unless location == SKIP
  @color_id = color_id unless color_id == SKIP
  @creator = creator unless creator == SKIP
  @organizer = organizer unless organizer == SKIP
  @start = start
  @mend = mend
  @end_time_unspecified = end_time_unspecified unless end_time_unspecified == SKIP
  @recurrence = recurrence unless recurrence == SKIP
  @recurring_event_id = recurring_event_id unless recurring_event_id == SKIP
  @original_start_time = original_start_time unless original_start_time == SKIP
  @transparency = transparency unless transparency == SKIP
  @visibility = visibility unless visibility == SKIP
  @i_cal_uid = i_cal_uid unless i_cal_uid == SKIP
  @sequence = sequence unless sequence == SKIP
  @attendees = attendees unless attendees == SKIP
  @attendees_omitted = attendees_omitted unless attendees_omitted == SKIP
  @hangout_link = hangout_link unless hangout_link == SKIP
  @conference_data = conference_data unless conference_data == SKIP
  @guests_can_invite_others = guests_can_invite_others unless guests_can_invite_others == SKIP
  @guests_can_modify = guests_can_modify unless guests_can_modify == SKIP
  unless guests_can_see_other_guests == SKIP
    @guests_can_see_other_guests =
      guests_can_see_other_guests
  end
  @private_copy = private_copy unless private_copy == SKIP
  @locked = locked unless locked == SKIP
  @reminders = reminders unless reminders == SKIP
  @source = source unless source == SKIP
  @event_type = event_type unless event_type == SKIP
  @extended_properties = extended_properties unless extended_properties == SKIP
  @attachments = attachments unless attachments == SKIP
  @birthday_properties = birthday_properties unless birthday_properties == SKIP
  @out_of_office_properties = out_of_office_properties unless out_of_office_properties == SKIP
  @focus_time_properties = focus_time_properties unless focus_time_properties == SKIP
  unless working_location_properties == SKIP
    @working_location_properties =
      working_location_properties
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#attachmentsArray[Attachment]

File attachments for the event. Maximum 25 attachments per event.

Returns:



174
175
176
# File 'lib/calendar_api/models/event.rb', line 174

def attachments
  @attachments
end

#attendeesArray[Attendee]

The attendees of the event.

Returns:



119
120
121
# File 'lib/calendar_api/models/event.rb', line 119

def attendees
  @attendees
end

#attendees_omittedTrueClass | FalseClass

Whether attendees may have been omitted from the event’s representation.

Returns:

  • (TrueClass | FalseClass)


123
124
125
# File 'lib/calendar_api/models/event.rb', line 123

def attendees_omitted
  @attendees_omitted
end

#birthday_propertiesBirthdayProperties

Birthday or special event data. Used if eventType is birthday.

Returns:



178
179
180
# File 'lib/calendar_api/models/event.rb', line 178

def birthday_properties
  @birthday_properties
end

#color_idString

The color of the event. This is an ID referring to an entry in the event section of the colors definition.

Returns:

  • (String)


58
59
60
# File 'lib/calendar_api/models/event.rb', line 58

def color_id
  @color_id
end

#conference_dataConferenceData

Information about a conference (e.g. Google Meet).

Returns:



132
133
134
# File 'lib/calendar_api/models/event.rb', line 132

def conference_data
  @conference_data
end

#createdDateTime

Creation time of the event (RFC3339).

Returns:

  • (DateTime)


37
38
39
# File 'lib/calendar_api/models/event.rb', line 37

def created
  @created
end

#creatorPerson

Identifies a person associated with the event, such as the creator or organizer.

Returns:



63
64
65
# File 'lib/calendar_api/models/event.rb', line 63

def creator
  @creator
end

#descriptionString

Description of the event. Can contain HTML.

Returns:

  • (String)


49
50
51
# File 'lib/calendar_api/models/event.rb', line 49

def description
  @description
end

#end_time_unspecifiedTrueClass | FalseClass

Whether the end time is actually unspecified.

Returns:

  • (TrueClass | FalseClass)


82
83
84
# File 'lib/calendar_api/models/event.rb', line 82

def end_time_unspecified
  @end_time_unspecified
end

#etagString

ETag of the resource.

Returns:

  • (String)


19
20
21
# File 'lib/calendar_api/models/event.rb', line 19

def etag
  @etag
end

#event_typeEventType

The specific type of event.

Returns:



166
167
168
# File 'lib/calendar_api/models/event.rb', line 166

def event_type
  @event_type
end

#extended_propertiesExtendedProperties

Extended properties of the event.

Returns:



170
171
172
# File 'lib/calendar_api/models/event.rb', line 170

def extended_properties
  @extended_properties
end

#focus_time_propertiesFocusTimeProperties

Focus time event data. Used if eventType is focusTime.

Returns:



186
187
188
# File 'lib/calendar_api/models/event.rb', line 186

def focus_time_properties
  @focus_time_properties
end

#guests_can_invite_othersTrueClass | FalseClass

Whether attendees other than the organizer can invite others.

Returns:

  • (TrueClass | FalseClass)


136
137
138
# File 'lib/calendar_api/models/event.rb', line 136

def guests_can_invite_others
  @guests_can_invite_others
end

#guests_can_modifyTrueClass | FalseClass

Whether attendees other than the organizer can modify the event.

Returns:

  • (TrueClass | FalseClass)


140
141
142
# File 'lib/calendar_api/models/event.rb', line 140

def guests_can_modify
  @guests_can_modify
end

#guests_can_see_other_guestsTrueClass | FalseClass

Whether attendees other than the organizer can see who the event’s attendees are.

Returns:

  • (TrueClass | FalseClass)


145
146
147
# File 'lib/calendar_api/models/event.rb', line 145

def guests_can_see_other_guests
  @guests_can_see_other_guests
end

An absolute link to the Google Hangout associated with this event (deprecated in favor of conferenceData).

Returns:

  • (String)


128
129
130
# File 'lib/calendar_api/models/event.rb', line 128

def hangout_link
  @hangout_link
end

Absolute link to this event in the Google Calendar Web UI.

Returns:

  • (String)


33
34
35
# File 'lib/calendar_api/models/event.rb', line 33

def html_link
  @html_link
end

#i_cal_uidString

Event unique identifier as defined in RFC 5545.

Returns:

  • (String)


111
112
113
# File 'lib/calendar_api/models/event.rb', line 111

def i_cal_uid
  @i_cal_uid
end

#idString

Opaque identifier of the event. When creating new single or recurring events, you can specify their IDs. Event IDs must be between 5 and 1024 characters long and consist of lower-case base32hex characters (a-v, 0-9).

Returns:

  • (String)


25
26
27
# File 'lib/calendar_api/models/event.rb', line 25

def id
  @id
end

#kindString

Type of the resource.

Returns:

  • (String)


15
16
17
# File 'lib/calendar_api/models/event.rb', line 15

def kind
  @kind
end

#locationString

Geographic location of the event as free-form text.

Returns:

  • (String)


53
54
55
# File 'lib/calendar_api/models/event.rb', line 53

def location
  @location
end

#lockedTrueClass | FalseClass

Whether this is a locked event copy where no changes can be made.

Returns:

  • (TrueClass | FalseClass)


153
154
155
# File 'lib/calendar_api/models/event.rb', line 153

def locked
  @locked
end

#mendEventDateTime

A timestamp marking the start or end of an event. For all-day events, use date; for timed events, use dateTime.

Returns:



78
79
80
# File 'lib/calendar_api/models/event.rb', line 78

def mend
  @mend
end

#organizerPerson

Identifies a person associated with the event, such as the creator or organizer.

Returns:



68
69
70
# File 'lib/calendar_api/models/event.rb', line 68

def organizer
  @organizer
end

#original_start_timeEventDateTime

A timestamp marking the start or end of an event. For all-day events, use date; for timed events, use dateTime.

Returns:



98
99
100
# File 'lib/calendar_api/models/event.rb', line 98

def original_start_time
  @original_start_time
end

#out_of_office_propertiesOutOfOfficeProperties

Out-of-office event data. Used if eventType is outOfOffice.



182
183
184
# File 'lib/calendar_api/models/event.rb', line 182

def out_of_office_properties
  @out_of_office_properties
end

#private_copyTrueClass | FalseClass

If set to true, event propagation is disabled.

Returns:

  • (TrueClass | FalseClass)


149
150
151
# File 'lib/calendar_api/models/event.rb', line 149

def private_copy
  @private_copy
end

#recurrenceArray[String]

List of RRULE, EXRULE, RDATE, and EXDATE lines for a recurring event, as specified in RFC 5545. This field is omitted for single events or instances of recurring events.

Returns:

  • (Array[String])


88
89
90
# File 'lib/calendar_api/models/event.rb', line 88

def recurrence
  @recurrence
end

#recurring_event_idString

For an instance of a recurring event, this is the ID of the recurring event to which this instance belongs.

Returns:

  • (String)


93
94
95
# File 'lib/calendar_api/models/event.rb', line 93

def recurring_event_id
  @recurring_event_id
end

#remindersEventReminders

Information about the event’s reminders.

Returns:



157
158
159
# File 'lib/calendar_api/models/event.rb', line 157

def reminders
  @reminders
end

#sequenceInteger

Sequence number as per iCalendar.

Returns:

  • (Integer)


115
116
117
# File 'lib/calendar_api/models/event.rb', line 115

def sequence
  @sequence
end

#sourceEventSource

Source from which the event was created — for example, a web page or an email message.

Returns:



162
163
164
# File 'lib/calendar_api/models/event.rb', line 162

def source
  @source
end

#startEventDateTime

A timestamp marking the start or end of an event. For all-day events, use date; for timed events, use dateTime.

Returns:



73
74
75
# File 'lib/calendar_api/models/event.rb', line 73

def start
  @start
end

#statusEventStatus

Status of the event.

Returns:



29
30
31
# File 'lib/calendar_api/models/event.rb', line 29

def status
  @status
end

#summaryString

Title of the event.

Returns:

  • (String)


45
46
47
# File 'lib/calendar_api/models/event.rb', line 45

def summary
  @summary
end

#transparencyEventTransparency

Whether the event blocks time on the calendar. “opaque” means the event does block time; “transparent” means it does not.

Returns:



103
104
105
# File 'lib/calendar_api/models/event.rb', line 103

def transparency
  @transparency
end

#updatedDateTime

Last modification time of the event (RFC3339).

Returns:

  • (DateTime)


41
42
43
# File 'lib/calendar_api/models/event.rb', line 41

def updated
  @updated
end

#visibilityEventVisibility

Visibility of the event.

Returns:



107
108
109
# File 'lib/calendar_api/models/event.rb', line 107

def visibility
  @visibility
end

#working_location_propertiesWorkingLocationProperties

Working location event data. Used if eventType is workingLocation.



190
191
192
# File 'lib/calendar_api/models/event.rb', line 190

def working_location_properties
  @working_location_properties
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/calendar_api/models/event.rb', line 361

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  start = EventDateTime.from_hash(hash['start']) if hash['start']
  mend = EventDateTime.from_hash(hash['end']) if hash['end']
  kind = hash['kind'] ||= 'calendar#event'
  etag = hash.key?('etag') ? hash['etag'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  html_link = hash.key?('htmlLink') ? hash['htmlLink'] : SKIP
  created = if hash.key?('created')
              (DateTimeHelper.from_rfc3339(hash['created']) if hash['created'])
            else
              SKIP
            end
  updated = if hash.key?('updated')
              (DateTimeHelper.from_rfc3339(hash['updated']) if hash['updated'])
            else
              SKIP
            end
  summary = hash.key?('summary') ? hash['summary'] : SKIP
  description = hash.key?('description') ? hash['description'] : SKIP
  location = hash.key?('location') ? hash['location'] : SKIP
  color_id = hash.key?('colorId') ? hash['colorId'] : SKIP
  creator = Person.from_hash(hash['creator']) if hash['creator']
  organizer = Person.from_hash(hash['organizer']) if hash['organizer']
  end_time_unspecified = hash['endTimeUnspecified'] ||= false
  recurrence = hash.key?('recurrence') ? hash['recurrence'] : SKIP
  recurring_event_id =
    hash.key?('recurringEventId') ? hash['recurringEventId'] : SKIP
  original_start_time = EventDateTime.from_hash(hash['originalStartTime']) if
    hash['originalStartTime']
  transparency = hash['transparency'] ||= EventTransparency::OPAQUE
  visibility = hash['visibility'] ||= EventVisibility::DEFAULT
  i_cal_uid = hash.key?('iCalUID') ? hash['iCalUID'] : SKIP
  sequence = hash.key?('sequence') ? hash['sequence'] : SKIP
  # Parameter is an array, so we need to iterate through it
  attendees = nil
  unless hash['attendees'].nil?
    attendees = []
    hash['attendees'].each do |structure|
      attendees << (Attendee.from_hash(structure) if structure)
    end
  end

  attendees = SKIP unless hash.key?('attendees')
  attendees_omitted = hash['attendeesOmitted'] ||= false
  hangout_link = hash.key?('hangoutLink') ? hash['hangoutLink'] : SKIP
  conference_data = ConferenceData.from_hash(hash['conferenceData']) if hash['conferenceData']
  guests_can_invite_others = hash['guestsCanInviteOthers'] ||= true
  guests_can_modify = hash['guestsCanModify'] ||= false
  guests_can_see_other_guests = hash['guestsCanSeeOtherGuests'] ||= true
  private_copy = hash['privateCopy'] ||= false
  locked = hash['locked'] ||= false
  reminders = EventReminders.from_hash(hash['reminders']) if hash['reminders']
  source = EventSource.from_hash(hash['source']) if hash['source']
  event_type = hash.key?('eventType') ? hash['eventType'] : SKIP
  extended_properties = ExtendedProperties.from_hash(hash['extendedProperties']) if
    hash['extendedProperties']
  # Parameter is an array, so we need to iterate through it
  attachments = nil
  unless hash['attachments'].nil?
    attachments = []
    hash['attachments'].each do |structure|
      attachments << (Attachment.from_hash(structure) if structure)
    end
  end

  attachments = SKIP unless hash.key?('attachments')
  birthday_properties = BirthdayProperties.from_hash(hash['birthdayProperties']) if
    hash['birthdayProperties']
  out_of_office_properties = OutOfOfficeProperties.from_hash(hash['outOfOfficeProperties']) if
    hash['outOfOfficeProperties']
  focus_time_properties = FocusTimeProperties.from_hash(hash['focusTimeProperties']) if
    hash['focusTimeProperties']
  if hash['workingLocationProperties']
    working_location_properties = WorkingLocationProperties.from_hash(hash['workingLocationProperties'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Event.new(start: start,
            mend: mend,
            kind: kind,
            etag: etag,
            id: id,
            status: status,
            html_link: html_link,
            created: created,
            updated: updated,
            summary: summary,
            description: description,
            location: location,
            color_id: color_id,
            creator: creator,
            organizer: organizer,
            end_time_unspecified: end_time_unspecified,
            recurrence: recurrence,
            recurring_event_id: recurring_event_id,
            original_start_time: original_start_time,
            transparency: transparency,
            visibility: visibility,
            i_cal_uid: i_cal_uid,
            sequence: sequence,
            attendees: attendees,
            attendees_omitted: attendees_omitted,
            hangout_link: hangout_link,
            conference_data: conference_data,
            guests_can_invite_others: guests_can_invite_others,
            guests_can_modify: guests_can_modify,
            guests_can_see_other_guests: guests_can_see_other_guests,
            private_copy: private_copy,
            locked: locked,
            reminders: reminders,
            source: source,
            event_type: event_type,
            extended_properties: extended_properties,
            attachments: attachments,
            birthday_properties: birthday_properties,
            out_of_office_properties: out_of_office_properties,
            focus_time_properties: focus_time_properties,
            working_location_properties: working_location_properties,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/calendar_api/models/event.rb', line 193

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['kind'] = 'kind'
  @_hash['etag'] = 'etag'
  @_hash['id'] = 'id'
  @_hash['status'] = 'status'
  @_hash['html_link'] = 'htmlLink'
  @_hash['created'] = 'created'
  @_hash['updated'] = 'updated'
  @_hash['summary'] = 'summary'
  @_hash['description'] = 'description'
  @_hash['location'] = 'location'
  @_hash['color_id'] = 'colorId'
  @_hash['creator'] = 'creator'
  @_hash['organizer'] = 'organizer'
  @_hash['start'] = 'start'
  @_hash['mend'] = 'end'
  @_hash['end_time_unspecified'] = 'endTimeUnspecified'
  @_hash['recurrence'] = 'recurrence'
  @_hash['recurring_event_id'] = 'recurringEventId'
  @_hash['original_start_time'] = 'originalStartTime'
  @_hash['transparency'] = 'transparency'
  @_hash['visibility'] = 'visibility'
  @_hash['i_cal_uid'] = 'iCalUID'
  @_hash['sequence'] = 'sequence'
  @_hash['attendees'] = 'attendees'
  @_hash['attendees_omitted'] = 'attendeesOmitted'
  @_hash['hangout_link'] = 'hangoutLink'
  @_hash['conference_data'] = 'conferenceData'
  @_hash['guests_can_invite_others'] = 'guestsCanInviteOthers'
  @_hash['guests_can_modify'] = 'guestsCanModify'
  @_hash['guests_can_see_other_guests'] = 'guestsCanSeeOtherGuests'
  @_hash['private_copy'] = 'privateCopy'
  @_hash['locked'] = 'locked'
  @_hash['reminders'] = 'reminders'
  @_hash['source'] = 'source'
  @_hash['event_type'] = 'eventType'
  @_hash['extended_properties'] = 'extendedProperties'
  @_hash['attachments'] = 'attachments'
  @_hash['birthday_properties'] = 'birthdayProperties'
  @_hash['out_of_office_properties'] = 'outOfOfficeProperties'
  @_hash['focus_time_properties'] = 'focusTimeProperties'
  @_hash['working_location_properties'] = 'workingLocationProperties'
  @_hash
end

.nullablesObject

An array for nullable fields



285
286
287
# File 'lib/calendar_api/models/event.rb', line 285

def self.nullables
  []
end

.optionalsObject

An array for optional fields



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/calendar_api/models/event.rb', line 240

def self.optionals
  %w[
    kind
    etag
    id
    status
    html_link
    created
    updated
    summary
    description
    location
    color_id
    creator
    organizer
    end_time_unspecified
    recurrence
    recurring_event_id
    original_start_time
    transparency
    visibility
    i_cal_uid
    sequence
    attendees
    attendees_omitted
    hangout_link
    conference_data
    guests_can_invite_others
    guests_can_modify
    guests_can_see_other_guests
    private_copy
    locked
    reminders
    source
    event_type
    extended_properties
    attachments
    birthday_properties
    out_of_office_properties
    focus_time_properties
    working_location_properties
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'lib/calendar_api/models/event.rb', line 525

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} kind: #{@kind.inspect}, etag: #{@etag.inspect}, id: #{@id.inspect}, status:"\
  " #{@status.inspect}, html_link: #{@html_link.inspect}, created: #{@created.inspect},"\
  " updated: #{@updated.inspect}, summary: #{@summary.inspect}, description:"\
  " #{@description.inspect}, location: #{@location.inspect}, color_id: #{@color_id.inspect},"\
  " creator: #{@creator.inspect}, organizer: #{@organizer.inspect}, start: #{@start.inspect},"\
  " mend: #{@mend.inspect}, end_time_unspecified: #{@end_time_unspecified.inspect},"\
  " recurrence: #{@recurrence.inspect}, recurring_event_id: #{@recurring_event_id.inspect},"\
  " original_start_time: #{@original_start_time.inspect}, transparency:"\
  " #{@transparency.inspect}, visibility: #{@visibility.inspect}, i_cal_uid:"\
  " #{@i_cal_uid.inspect}, sequence: #{@sequence.inspect}, attendees: #{@attendees.inspect},"\
  " attendees_omitted: #{@attendees_omitted.inspect}, hangout_link: #{@hangout_link.inspect},"\
  " conference_data: #{@conference_data.inspect}, guests_can_invite_others:"\
  " #{@guests_can_invite_others.inspect}, guests_can_modify: #{@guests_can_modify.inspect},"\
  " guests_can_see_other_guests: #{@guests_can_see_other_guests.inspect}, private_copy:"\
  " #{@private_copy.inspect}, locked: #{@locked.inspect}, reminders: #{@reminders.inspect},"\
  " source: #{@source.inspect}, event_type: #{@event_type.inspect}, extended_properties:"\
  " #{@extended_properties.inspect}, attachments: #{@attachments.inspect},"\
  " birthday_properties: #{@birthday_properties.inspect}, out_of_office_properties:"\
  " #{@out_of_office_properties.inspect}, focus_time_properties:"\
  " #{@focus_time_properties.inspect}, working_location_properties:"\
  " #{@working_location_properties.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_createdObject



493
494
495
# File 'lib/calendar_api/models/event.rb', line 493

def to_custom_created
  DateTimeHelper.to_rfc3339(created)
end

#to_custom_updatedObject



497
498
499
# File 'lib/calendar_api/models/event.rb', line 497

def to_custom_updated
  DateTimeHelper.to_rfc3339(updated)
end

#to_sObject

Provides a human-readable string representation of the object.



502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/calendar_api/models/event.rb', line 502

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} kind: #{@kind}, etag: #{@etag}, id: #{@id}, status: #{@status}, html_link:"\
  " #{@html_link}, created: #{@created}, updated: #{@updated}, summary: #{@summary},"\
  " description: #{@description}, location: #{@location}, color_id: #{@color_id}, creator:"\
  " #{@creator}, organizer: #{@organizer}, start: #{@start}, mend: #{@mend},"\
  " end_time_unspecified: #{@end_time_unspecified}, recurrence: #{@recurrence},"\
  " recurring_event_id: #{@recurring_event_id}, original_start_time: #{@original_start_time},"\
  " transparency: #{@transparency}, visibility: #{@visibility}, i_cal_uid: #{@i_cal_uid},"\
  " sequence: #{@sequence}, attendees: #{@attendees}, attendees_omitted:"\
  " #{@attendees_omitted}, hangout_link: #{@hangout_link}, conference_data:"\
  " #{@conference_data}, guests_can_invite_others: #{@guests_can_invite_others},"\
  " guests_can_modify: #{@guests_can_modify}, guests_can_see_other_guests:"\
  " #{@guests_can_see_other_guests}, private_copy: #{@private_copy}, locked: #{@locked},"\
  " reminders: #{@reminders}, source: #{@source}, event_type: #{@event_type},"\
  " extended_properties: #{@extended_properties}, attachments: #{@attachments},"\
  " birthday_properties: #{@birthday_properties}, out_of_office_properties:"\
  " #{@out_of_office_properties}, focus_time_properties: #{@focus_time_properties},"\
  " working_location_properties: #{@working_location_properties}, additional_properties:"\
  " #{@additional_properties}>"
end