Class: CalendarApi::EventReminders

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/event_reminders.rb

Overview

Information about the event’s reminders.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(use_default: SKIP, overrides: SKIP, additional_properties: nil) ⇒ EventReminders

Returns a new instance of EventReminders.



41
42
43
44
45
46
47
48
49
# File 'lib/calendar_api/models/event_reminders.rb', line 41

def initialize(use_default: SKIP, overrides: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @use_default = use_default unless use_default == SKIP
  @overrides = overrides unless overrides == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#overridesArray[Reminder]

Overrides to apply instead of default reminders. Maximum 5 overrides.

Returns:



18
19
20
# File 'lib/calendar_api/models/event_reminders.rb', line 18

def overrides
  @overrides
end

#use_defaultTrueClass | FalseClass

Whether the default reminders of the calendar apply to the event.

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/calendar_api/models/event_reminders.rb', line 14

def use_default
  @use_default
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/calendar_api/models/event_reminders.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  use_default = hash.key?('useDefault') ? hash['useDefault'] : SKIP
  # Parameter is an array, so we need to iterate through it
  overrides = nil
  unless hash['overrides'].nil?
    overrides = []
    hash['overrides'].each do |structure|
      overrides << (Reminder.from_hash(structure) if structure)
    end
  end

  overrides = SKIP unless hash.key?('overrides')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EventReminders.new(use_default: use_default,
                     overrides: overrides,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/calendar_api/models/event_reminders.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['use_default'] = 'useDefault'
  @_hash['overrides'] = 'overrides'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/calendar_api/models/event_reminders.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/calendar_api/models/event_reminders.rb', line 29

def self.optionals
  %w[
    use_default
    overrides
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/calendar_api/models/event_reminders.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} use_default: #{@use_default.inspect}, overrides: #{@overrides.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/calendar_api/models/event_reminders.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} use_default: #{@use_default}, overrides: #{@overrides},"\
  " additional_properties: #{@additional_properties}>"
end