Class: CalendarApi::EventSource

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/event_source.rb

Overview

Source from which the event was created — for example, a web page or an email message.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(url: SKIP, title: SKIP, additional_properties: nil) ⇒ EventSource

Returns a new instance of EventSource.



42
43
44
45
46
47
48
49
# File 'lib/calendar_api/models/event_source.rb', line 42

def initialize(url: SKIP, title: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @url = url unless url == SKIP
  @title = title unless title == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#titleString

Title of the source (e.g. a web page or email subject).

Returns:

  • (String)


19
20
21
# File 'lib/calendar_api/models/event_source.rb', line 19

def title
  @title
end

#urlString

URL of the source pointing to a resource.

Returns:

  • (String)


15
16
17
# File 'lib/calendar_api/models/event_source.rb', line 15

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/calendar_api/models/event_source.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  url = hash.key?('url') ? hash['url'] : SKIP
  title = hash.key?('title') ? hash['title'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EventSource.new(url: url,
                  title: title,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/calendar_api/models/event_source.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['url'] = 'url'
  @_hash['title'] = 'title'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/calendar_api/models/event_source.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/calendar_api/models/event_source.rb', line 30

def self.optionals
  %w[
    url
    title
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/calendar_api/models/event_source.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url.inspect}, title: #{@title.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/calendar_api/models/event_source.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url}, title: #{@title}, additional_properties:"\
  " #{@additional_properties}>"
end