Class: CalendarApi::ExtendedProperties

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/extended_properties.rb

Overview

Extended properties of the event.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(private: SKIP, shared: SKIP, additional_properties: nil) ⇒ ExtendedProperties

Returns a new instance of ExtendedProperties.



43
44
45
46
47
48
49
50
# File 'lib/calendar_api/models/extended_properties.rb', line 43

def initialize(private: SKIP, shared: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @private = private unless private == SKIP
  @shared = shared unless shared == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#privateHash[String, String]

Properties that are private to the copy of the event that appears on this calendar.

Returns:

  • (Hash[String, String])


15
16
17
# File 'lib/calendar_api/models/extended_properties.rb', line 15

def private
  @private
end

#sharedHash[String, String]

Properties that are shared between copies of the event on other attendees’ calendars.

Returns:

  • (Hash[String, String])


20
21
22
# File 'lib/calendar_api/models/extended_properties.rb', line 20

def shared
  @shared
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/calendar_api/models/extended_properties.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  private = hash.key?('private') ? hash['private'] : SKIP
  shared = hash.key?('shared') ? hash['shared'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ExtendedProperties.new(private: private,
                         shared: shared,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/calendar_api/models/extended_properties.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['private'] = 'private'
  @_hash['shared'] = 'shared'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/calendar_api/models/extended_properties.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/calendar_api/models/extended_properties.rb', line 31

def self.optionals
  %w[
    private
    shared
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/calendar_api/models/extended_properties.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} private: #{@private.inspect}, shared: #{@shared.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/calendar_api/models/extended_properties.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} private: #{@private}, shared: #{@shared}, additional_properties:"\
  " #{@additional_properties}>"
end