Class: CalendarApi::FocusTimeProperties

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/focus_time_properties.rb

Overview

Focus time event data. Used if eventType is focusTime.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(auto_decline_mode: SKIP, decline_message: SKIP, chat_status: SKIP, additional_properties: nil) ⇒ FocusTimeProperties

Returns a new instance of FocusTimeProperties.



47
48
49
50
51
52
53
54
55
56
# File 'lib/calendar_api/models/focus_time_properties.rb', line 47

def initialize(auto_decline_mode: SKIP, decline_message: SKIP,
               chat_status: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @auto_decline_mode = auto_decline_mode unless auto_decline_mode == SKIP
  @decline_message = decline_message unless decline_message == SKIP
  @chat_status = chat_status unless chat_status == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#auto_decline_modeAutoDeclineMode

Whether to auto-decline conflicting meeting invitations.

Returns:



14
15
16
# File 'lib/calendar_api/models/focus_time_properties.rb', line 14

def auto_decline_mode
  @auto_decline_mode
end

#chat_statusChatStatus

Chat status during focus time.

Returns:



22
23
24
# File 'lib/calendar_api/models/focus_time_properties.rb', line 22

def chat_status
  @chat_status
end

#decline_messageString

Response message to set when auto-declining invitations.

Returns:

  • (String)


18
19
20
# File 'lib/calendar_api/models/focus_time_properties.rb', line 18

def decline_message
  @decline_message
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/calendar_api/models/focus_time_properties.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  auto_decline_mode =
    hash.key?('autoDeclineMode') ? hash['autoDeclineMode'] : SKIP
  decline_message =
    hash.key?('declineMessage') ? hash['declineMessage'] : SKIP
  chat_status = hash.key?('chatStatus') ? hash['chatStatus'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FocusTimeProperties.new(auto_decline_mode: auto_decline_mode,
                          decline_message: decline_message,
                          chat_status: chat_status,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/calendar_api/models/focus_time_properties.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['auto_decline_mode'] = 'autoDeclineMode'
  @_hash['decline_message'] = 'declineMessage'
  @_hash['chat_status'] = 'chatStatus'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/calendar_api/models/focus_time_properties.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/calendar_api/models/focus_time_properties.rb', line 34

def self.optionals
  %w[
    auto_decline_mode
    decline_message
    chat_status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/calendar_api/models/focus_time_properties.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} auto_decline_mode: #{@auto_decline_mode.inspect}, decline_message:"\
  " #{@decline_message.inspect}, chat_status: #{@chat_status.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
89
# File 'lib/calendar_api/models/focus_time_properties.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} auto_decline_mode: #{@auto_decline_mode}, decline_message:"\
  " #{@decline_message}, chat_status: #{@chat_status}, additional_properties:"\
  " #{@additional_properties}>"
end