Class: CalendarApi::FreeBusyCalendar

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/free_busy_calendar.rb

Overview

Free/busy data for a single calendar.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(busy: SKIP, errors: SKIP, additional_properties: nil) ⇒ FreeBusyCalendar

Returns a new instance of FreeBusyCalendar.



41
42
43
44
45
46
47
48
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 41

def initialize(busy: SKIP, errors: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @busy = busy unless busy == SKIP
  @errors = errors unless errors == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#busyArray[TimePeriod]

List of time ranges during which this calendar is busy.

Returns:



14
15
16
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 14

def busy
  @busy
end

#errorsArray[FreeBusyError]

Optional errors for this calendar.

Returns:



18
19
20
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 18

def errors
  @errors
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  busy = nil
  unless hash['busy'].nil?
    busy = []
    hash['busy'].each do |structure|
      busy << (TimePeriod.from_hash(structure) if structure)
    end
  end

  busy = SKIP unless hash.key?('busy')
  # Parameter is an array, so we need to iterate through it
  errors = nil
  unless hash['errors'].nil?
    errors = []
    hash['errors'].each do |structure|
      errors << (FreeBusyError.from_hash(structure) if structure)
    end
  end

  errors = SKIP unless hash.key?('errors')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FreeBusyCalendar.new(busy: busy,
                       errors: errors,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['busy'] = 'busy'
  @_hash['errors'] = 'errors'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 29

def self.optionals
  %w[
    busy
    errors
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} busy: #{@busy.inspect}, errors: #{@errors.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/calendar_api/models/free_busy_calendar.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} busy: #{@busy}, errors: #{@errors}, additional_properties:"\
  " #{@additional_properties}>"
end