Class: CalendarApi::FreeBusyError

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/free_busy_error.rb

Overview

An error associated with a free/busy calendar or group query.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(domain: SKIP, reason: SKIP, additional_properties: nil) ⇒ FreeBusyError

Returns a new instance of FreeBusyError.



41
42
43
44
45
46
47
48
# File 'lib/calendar_api/models/free_busy_error.rb', line 41

def initialize(domain: SKIP, reason: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @domain = domain unless domain == SKIP
  @reason = reason unless reason == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#domainString

The error domain.

Returns:

  • (String)


14
15
16
# File 'lib/calendar_api/models/free_busy_error.rb', line 14

def domain
  @domain
end

#reasonString

The error reason code.

Returns:

  • (String)


18
19
20
# File 'lib/calendar_api/models/free_busy_error.rb', line 18

def reason
  @reason
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/calendar_api/models/free_busy_error.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  domain = hash.key?('domain') ? hash['domain'] : SKIP
  reason = hash.key?('reason') ? hash['reason'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FreeBusyError.new(domain: domain,
                    reason: reason,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/calendar_api/models/free_busy_error.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['domain'] = 'domain'
  @_hash['reason'] = 'reason'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/calendar_api/models/free_busy_error.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/calendar_api/models/free_busy_error.rb', line 29

def self.optionals
  %w[
    domain
    reason
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/calendar_api/models/free_busy_error.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} domain: #{@domain.inspect}, reason: #{@reason.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/calendar_api/models/free_busy_error.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} domain: #{@domain}, reason: #{@reason}, additional_properties:"\
  " #{@additional_properties}>"
end