Class: CalendarApi::FreeBusyGroup
- Defined in:
- lib/calendar_api/models/free_busy_group.rb
Overview
Expansion result for a single group.
Instance Attribute Summary collapse
-
#calendars ⇒ Array[String]
List of calendars that are members of this group.
-
#errors ⇒ Array[FreeBusyError]
Optional errors for this group.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(calendars: SKIP, errors: SKIP, additional_properties: nil) ⇒ FreeBusyGroup
constructor
A new instance of FreeBusyGroup.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(calendars: SKIP, errors: SKIP, additional_properties: nil) ⇒ FreeBusyGroup
Returns a new instance of FreeBusyGroup.
41 42 43 44 45 46 47 48 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 41 def initialize(calendars: SKIP, errors: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @calendars = calendars unless calendars == SKIP @errors = errors unless errors == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#calendars ⇒ Array[String]
List of calendars that are members of this group.
14 15 16 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 14 def calendars @calendars end |
#errors ⇒ Array[FreeBusyError]
Optional errors for this group.
18 19 20 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 18 def errors @errors end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. calendars = hash.key?('calendars') ? hash['calendars'] : SKIP # Parameter is an array, so we need to iterate through it errors = nil unless hash['errors'].nil? errors = [] hash['errors'].each do |structure| errors << (FreeBusyError.from_hash(structure) if structure) end end errors = SKIP unless hash.key?('errors') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FreeBusyGroup.new(calendars: calendars, errors: errors, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['calendars'] = 'calendars' @_hash['errors'] = 'errors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 29 def self.optionals %w[ calendars errors ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} calendars: #{@calendars.inspect}, errors: #{@errors.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/calendar_api/models/free_busy_group.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} calendars: #{@calendars}, errors: #{@errors}, additional_properties:"\ " #{@additional_properties}>" end |