Class: CalendarApi::OfficeLocation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/office_location.rb

Overview

Office location details for a working location event.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(building_id: SKIP, floor_id: SKIP, floor_section_id: SKIP, desk_id: SKIP, label: SKIP, additional_properties: nil) ⇒ OfficeLocation

Returns a new instance of OfficeLocation.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/calendar_api/models/office_location.rb', line 59

def initialize(building_id: SKIP, floor_id: SKIP, floor_section_id: SKIP,
               desk_id: SKIP, label: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @building_id = building_id unless building_id == SKIP
  @floor_id = floor_id unless floor_id == SKIP
  @floor_section_id = floor_section_id unless floor_section_id == SKIP
  @desk_id = desk_id unless desk_id == SKIP
  @label = label unless label == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#building_idString

Building identifier.

Returns:

  • (String)


14
15
16
# File 'lib/calendar_api/models/office_location.rb', line 14

def building_id
  @building_id
end

#desk_idString

Desk identifier.

Returns:

  • (String)


26
27
28
# File 'lib/calendar_api/models/office_location.rb', line 26

def desk_id
  @desk_id
end

#floor_idString

Floor identifier.

Returns:

  • (String)


18
19
20
# File 'lib/calendar_api/models/office_location.rb', line 18

def floor_id
  @floor_id
end

#floor_section_idString

Floor section identifier.

Returns:

  • (String)


22
23
24
# File 'lib/calendar_api/models/office_location.rb', line 22

def floor_section_id
  @floor_section_id
end

#labelString

Office name displayed in Calendar Web and Mobile clients.

Returns:

  • (String)


30
31
32
# File 'lib/calendar_api/models/office_location.rb', line 30

def label
  @label
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/calendar_api/models/office_location.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  building_id = hash.key?('buildingId') ? hash['buildingId'] : SKIP
  floor_id = hash.key?('floorId') ? hash['floorId'] : SKIP
  floor_section_id =
    hash.key?('floorSectionId') ? hash['floorSectionId'] : SKIP
  desk_id = hash.key?('deskId') ? hash['deskId'] : SKIP
  label = hash.key?('label') ? hash['label'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OfficeLocation.new(building_id: building_id,
                     floor_id: floor_id,
                     floor_section_id: floor_section_id,
                     desk_id: desk_id,
                     label: label,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/calendar_api/models/office_location.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['building_id'] = 'buildingId'
  @_hash['floor_id'] = 'floorId'
  @_hash['floor_section_id'] = 'floorSectionId'
  @_hash['desk_id'] = 'deskId'
  @_hash['label'] = 'label'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/calendar_api/models/office_location.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/calendar_api/models/office_location.rb', line 44

def self.optionals
  %w[
    building_id
    floor_id
    floor_section_id
    desk_id
    label
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
# File 'lib/calendar_api/models/office_location.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} building_id: #{@building_id.inspect}, floor_id: #{@floor_id.inspect},"\
  " floor_section_id: #{@floor_section_id.inspect}, desk_id: #{@desk_id.inspect}, label:"\
  " #{@label.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
106
# File 'lib/calendar_api/models/office_location.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} building_id: #{@building_id}, floor_id: #{@floor_id}, floor_section_id:"\
  " #{@floor_section_id}, desk_id: #{@desk_id}, label: #{@label}, additional_properties:"\
  " #{@additional_properties}>"
end