Class: CalendarApi::Person

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/calendar_api/models/person.rb

Overview

Identifies a person associated with the event, such as the creator or organizer.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, email: SKIP, display_name: SKIP, mself: SKIP, additional_properties: nil) ⇒ Person

Returns a new instance of Person.



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/calendar_api/models/person.rb', line 54

def initialize(id: SKIP, email: SKIP, display_name: SKIP, mself: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @email = email unless email == SKIP
  @display_name = display_name unless display_name == SKIP
  @mself = mself unless mself == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#display_nameString

The person’s name.

Returns:

  • (String)


23
24
25
# File 'lib/calendar_api/models/person.rb', line 23

def display_name
  @display_name
end

#emailString

The person’s email address.

Returns:

  • (String)


19
20
21
# File 'lib/calendar_api/models/person.rb', line 19

def email
  @email
end

#idString

The person’s Profile ID.

Returns:

  • (String)


15
16
17
# File 'lib/calendar_api/models/person.rb', line 15

def id
  @id
end

#mselfTrueClass | FalseClass

Whether this person corresponds to the calendar owner.

Returns:

  • (TrueClass | FalseClass)


27
28
29
# File 'lib/calendar_api/models/person.rb', line 27

def mself
  @mself
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/calendar_api/models/person.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  email = hash.key?('email') ? hash['email'] : SKIP
  display_name = hash.key?('displayName') ? hash['displayName'] : SKIP
  mself = hash.key?('self') ? hash['self'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Person.new(id: id,
             email: email,
             display_name: display_name,
             mself: mself,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/calendar_api/models/person.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['email'] = 'email'
  @_hash['display_name'] = 'displayName'
  @_hash['mself'] = 'self'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/calendar_api/models/person.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
43
44
45
46
47
# File 'lib/calendar_api/models/person.rb', line 40

def self.optionals
  %w[
    id
    email
    display_name
    mself
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/calendar_api/models/person.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, email: #{@email.inspect}, display_name:"\
  " #{@display_name.inspect}, mself: #{@mself.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/calendar_api/models/person.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, email: #{@email}, display_name: #{@display_name}, mself:"\
  " #{@mself}, additional_properties: #{@additional_properties}>"
end