Class: CalendarApi::BirthdayProperties
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CalendarApi::BirthdayProperties
- Defined in:
- lib/calendar_api/models/birthday_properties.rb
Overview
Birthday or special event data. Used if eventType is birthday.
Instance Attribute Summary collapse
-
#contact ⇒ String
Resource name of the contact this birthday event is linked to.
-
#custom_type_name ⇒ String
Custom type label if type is “custom”.
-
#type ⇒ BirthdayType
Type of birthday or special event.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(contact: SKIP, type: SKIP, custom_type_name: SKIP, additional_properties: nil) ⇒ BirthdayProperties
constructor
A new instance of BirthdayProperties.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(contact: SKIP, type: SKIP, custom_type_name: SKIP, additional_properties: nil) ⇒ BirthdayProperties
Returns a new instance of BirthdayProperties.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 47 def initialize(contact: SKIP, type: SKIP, custom_type_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @contact = contact unless contact == SKIP @type = type unless type == SKIP @custom_type_name = custom_type_name unless custom_type_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#contact ⇒ String
Resource name of the contact this birthday event is linked to.
14 15 16 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 14 def contact @contact end |
#custom_type_name ⇒ String
Custom type label if type is “custom”.
22 23 24 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 22 def custom_type_name @custom_type_name end |
#type ⇒ BirthdayType
Type of birthday or special event.
18 19 20 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 18 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. contact = hash.key?('contact') ? hash['contact'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP custom_type_name = hash.key?('customTypeName') ? hash['customTypeName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BirthdayProperties.new(contact: contact, type: type, custom_type_name: custom_type_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['contact'] = 'contact' @_hash['type'] = 'type' @_hash['custom_type_name'] = 'customTypeName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 34 def self.optionals %w[ contact type custom_type_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} contact: #{@contact.inspect}, type: #{@type.inspect}, custom_type_name:"\ " #{@custom_type_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/calendar_api/models/birthday_properties.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} contact: #{@contact}, type: #{@type}, custom_type_name:"\ " #{@custom_type_name}, additional_properties: #{@additional_properties}>" end |