Class: CalendarApi::ConferenceSolution
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CalendarApi::ConferenceSolution
- Defined in:
- lib/calendar_api/models/conference_solution.rb
Overview
Conference solution information, such as Google Meet.
Instance Attribute Summary collapse
-
#icon_uri ⇒ String
User-visible icon for this solution.
-
#key ⇒ ConferenceSolutionKey
Identifies a conference solution type.
-
#name ⇒ String
User-visible name of the conference solution.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(key: SKIP, name: SKIP, icon_uri: SKIP, additional_properties: nil) ⇒ ConferenceSolution
constructor
A new instance of ConferenceSolution.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(key: SKIP, name: SKIP, icon_uri: SKIP, additional_properties: nil) ⇒ ConferenceSolution
Returns a new instance of ConferenceSolution.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/calendar_api/models/conference_solution.rb', line 47 def initialize(key: SKIP, name: SKIP, icon_uri: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @key = key unless key == SKIP @name = name unless name == SKIP @icon_uri = icon_uri unless icon_uri == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#icon_uri ⇒ String
User-visible icon for this solution.
22 23 24 |
# File 'lib/calendar_api/models/conference_solution.rb', line 22 def icon_uri @icon_uri end |
#key ⇒ ConferenceSolutionKey
Identifies a conference solution type.
14 15 16 |
# File 'lib/calendar_api/models/conference_solution.rb', line 14 def key @key end |
#name ⇒ String
User-visible name of the conference solution.
18 19 20 |
# File 'lib/calendar_api/models/conference_solution.rb', line 18 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/calendar_api/models/conference_solution.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. key = ConferenceSolutionKey.from_hash(hash['key']) if hash['key'] name = hash.key?('name') ? hash['name'] : SKIP icon_uri = hash.key?('iconUri') ? hash['iconUri'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ConferenceSolution.new(key: key, name: name, icon_uri: icon_uri, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/calendar_api/models/conference_solution.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['key'] = 'key' @_hash['name'] = 'name' @_hash['icon_uri'] = 'iconUri' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/calendar_api/models/conference_solution.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/calendar_api/models/conference_solution.rb', line 34 def self.optionals %w[ key name icon_uri ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/calendar_api/models/conference_solution.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} key: #{@key.inspect}, name: #{@name.inspect}, icon_uri:"\ " #{@icon_uri.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/calendar_api/models/conference_solution.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} key: #{@key}, name: #{@name}, icon_uri: #{@icon_uri},"\ " additional_properties: #{@additional_properties}>" end |