Class: CalendarApi::ErrorResponseErrorErrorsItems
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CalendarApi::ErrorResponseErrorErrorsItems
- Defined in:
- lib/calendar_api/models/error_response_error_errors_items.rb
Overview
ErrorResponseErrorErrorsItems object.
Instance Attribute Summary collapse
-
#domain ⇒ String
The error domain.
-
#message ⇒ String
A human-readable error message.
-
#reason ⇒ String
The error reason code.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(domain: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) ⇒ ErrorResponseErrorErrorsItems
constructor
A new instance of ErrorResponseErrorErrorsItems.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(domain: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) ⇒ ErrorResponseErrorErrorsItems
Returns a new instance of ErrorResponseErrorErrorsItems.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 47 def initialize(domain: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @domain = domain unless domain == SKIP @reason = reason unless reason == SKIP @message = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#domain ⇒ String
The error domain.
14 15 16 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 14 def domain @domain end |
#message ⇒ String
A human-readable error message.
22 23 24 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 22 def @message end |
#reason ⇒ String
The error reason code.
18 19 20 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 18 def reason @reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. domain = hash.key?('domain') ? hash['domain'] : SKIP reason = hash.key?('reason') ? hash['reason'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ErrorResponseErrorErrorsItems.new(domain: domain, reason: reason, message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['domain'] = 'domain' @_hash['reason'] = 'reason' @_hash['message'] = 'message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 34 def self.optionals %w[ domain reason message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} domain: #{@domain.inspect}, reason: #{@reason.inspect}, message:"\ " #{@message.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/calendar_api/models/error_response_error_errors_items.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} domain: #{@domain}, reason: #{@reason}, message: #{@message},"\ " additional_properties: #{@additional_properties}>" end |