Class: CalendarApi::OutOfOfficeProperties
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CalendarApi::OutOfOfficeProperties
- Defined in:
- lib/calendar_api/models/out_of_office_properties.rb
Overview
Out-of-office event data. Used if eventType is outOfOffice.
Instance Attribute Summary collapse
-
#auto_decline_mode ⇒ AutoDeclineMode
Whether to auto-decline conflicting meeting invitations.
-
#decline_message ⇒ String
Response message to set when auto-declining invitations.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(auto_decline_mode: SKIP, decline_message: SKIP, additional_properties: nil) ⇒ OutOfOfficeProperties
constructor
A new instance of OutOfOfficeProperties.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(auto_decline_mode: SKIP, decline_message: SKIP, additional_properties: nil) ⇒ OutOfOfficeProperties
Returns a new instance of OutOfOfficeProperties.
41 42 43 44 45 46 47 48 49 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 41 def initialize(auto_decline_mode: SKIP, decline_message: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @auto_decline_mode = auto_decline_mode unless auto_decline_mode == SKIP @decline_message = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#auto_decline_mode ⇒ AutoDeclineMode
Whether to auto-decline conflicting meeting invitations.
14 15 16 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 14 def auto_decline_mode @auto_decline_mode end |
#decline_message ⇒ String
Response message to set when auto-declining invitations.
18 19 20 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 18 def @decline_message end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. auto_decline_mode = hash.key?('autoDeclineMode') ? hash['autoDeclineMode'] : SKIP = hash.key?('declineMessage') ? hash['declineMessage'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OutOfOfficeProperties.new(auto_decline_mode: auto_decline_mode, decline_message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['auto_decline_mode'] = 'autoDeclineMode' @_hash['decline_message'] = 'declineMessage' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 29 def self.optionals %w[ auto_decline_mode decline_message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} auto_decline_mode: #{@auto_decline_mode.inspect}, decline_message:"\ " #{@decline_message.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/calendar_api/models/out_of_office_properties.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} auto_decline_mode: #{@auto_decline_mode}, decline_message:"\ " #{@decline_message}, additional_properties: #{@additional_properties}>" end |