Class: CalendarApi::Reminder
- Defined in:
- lib/calendar_api/models/reminder.rb
Overview
A reminder for an event.
Instance Attribute Summary collapse
-
#method ⇒ ReminderMethod
The method used by a reminder.
-
#minutes ⇒ Integer
Number of minutes before the start of the event when the reminder should trigger.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(method:, minutes:, additional_properties: nil) ⇒ Reminder
constructor
A new instance of Reminder.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(method:, minutes:, additional_properties: nil) ⇒ Reminder
Returns a new instance of Reminder.
39 40 41 42 43 44 45 46 |
# File 'lib/calendar_api/models/reminder.rb', line 39 def initialize(method:, minutes:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @method = method @minutes = minutes @additional_properties = additional_properties end |
Instance Attribute Details
#method ⇒ ReminderMethod
The method used by a reminder.
14 15 16 |
# File 'lib/calendar_api/models/reminder.rb', line 14 def method @method end |
#minutes ⇒ Integer
Number of minutes before the start of the event when the reminder should trigger. Valid values are between 0 and 40320 (4 weeks).
19 20 21 |
# File 'lib/calendar_api/models/reminder.rb', line 19 def minutes @minutes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/calendar_api/models/reminder.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. method = hash.key?('method') ? hash['method'] : nil minutes = hash.key?('minutes') ? hash['minutes'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Reminder.new(method: method, minutes: minutes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/calendar_api/models/reminder.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['method'] = 'method' @_hash['minutes'] = 'minutes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/calendar_api/models/reminder.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/calendar_api/models/reminder.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/calendar_api/models/reminder.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} method: #{@method.inspect}, minutes: #{@minutes.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/calendar_api/models/reminder.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} method: #{@method}, minutes: #{@minutes}, additional_properties:"\ " #{@additional_properties}>" end |