Class: CalendarApi::StopChannelRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CalendarApi::StopChannelRequest
- Defined in:
- lib/calendar_api/models/stop_channel_request.rb
Overview
Request body to stop a push notification channel. Requires the channel ID and resourceId returned from a previous watchEvents call.
Instance Attribute Summary collapse
-
#id ⇒ String
The UUID or unique string that identifies the channel, as provided when the channel was created.
-
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, resource_id:, additional_properties: nil) ⇒ StopChannelRequest
constructor
A new instance of StopChannelRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, resource_id:, additional_properties: nil) ⇒ StopChannelRequest
Returns a new instance of StopChannelRequest.
41 42 43 44 45 46 47 48 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 41 def initialize(id:, resource_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @resource_id = resource_id @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
The UUID or unique string that identifies the channel, as provided when the channel was created.
16 17 18 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 16 def id @id end |
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel. Returned in the watchEvents response.
21 22 23 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 21 def resource_id @resource_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil resource_id = hash.key?('resourceId') ? hash['resourceId'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. StopChannelRequest.new(id: id, resource_id: resource_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['resource_id'] = 'resourceId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 32 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, resource_id: #{@resource_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/calendar_api/models/stop_channel_request.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, resource_id: #{@resource_id}, additional_properties:"\ " #{@additional_properties}>" end |