Class: CalendarApi::TimePeriod
- Defined in:
- lib/calendar_api/models/time_period.rb
Overview
A time range representing a busy period.
Instance Attribute Summary collapse
-
#mend ⇒ DateTime
The end of the busy time period (exclusive).
-
#start ⇒ DateTime
The start of the busy time period (inclusive).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start: SKIP, mend: SKIP, additional_properties: nil) ⇒ TimePeriod
constructor
A new instance of TimePeriod.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_mend ⇒ Object
- #to_custom_start ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start: SKIP, mend: SKIP, additional_properties: nil) ⇒ TimePeriod
Returns a new instance of TimePeriod.
42 43 44 45 46 47 48 49 |
# File 'lib/calendar_api/models/time_period.rb', line 42 def initialize(start: SKIP, mend: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start = start unless start == SKIP @mend = mend unless mend == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mend ⇒ DateTime
The end of the busy time period (exclusive).
19 20 21 |
# File 'lib/calendar_api/models/time_period.rb', line 19 def mend @mend end |
#start ⇒ DateTime
The start of the busy time period (inclusive).
15 16 17 |
# File 'lib/calendar_api/models/time_period.rb', line 15 def start @start end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/calendar_api/models/time_period.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start = if hash.key?('start') (DateTimeHelper.from_rfc3339(hash['start']) if hash['start']) else SKIP end mend = if hash.key?('end') (DateTimeHelper.from_rfc3339(hash['end']) if hash['end']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TimePeriod.new(start: start, mend: mend, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/calendar_api/models/time_period.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['start'] = 'start' @_hash['mend'] = 'end' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/calendar_api/models/time_period.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/calendar_api/models/time_period.rb', line 30 def self.optionals %w[ start mend ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 |
# File 'lib/calendar_api/models/time_period.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} start: #{@start.inspect}, mend: #{@mend.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_custom_mend ⇒ Object
84 85 86 |
# File 'lib/calendar_api/models/time_period.rb', line 84 def to_custom_mend DateTimeHelper.to_rfc3339(mend) end |
#to_custom_start ⇒ Object
80 81 82 |
# File 'lib/calendar_api/models/time_period.rb', line 80 def to_custom_start DateTimeHelper.to_rfc3339(start) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/calendar_api/models/time_period.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} start: #{@start}, mend: #{@mend}, additional_properties:"\ " #{@additional_properties}>" end |